library(testthat)
library(fasstr)
suppressMessages(library(dplyr))

test_check("fasstr")
